==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/CommodityChannelIndexIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { CommodityChannelIndexIndicatorDescription } from "./CommodityChannelIndexIndicatorDescription";
/**
 * @hidden
 */
export let CommodityChannelIndexIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class CommodityChannelIndexIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (CommodityChannelIndexIndicatorDescriptionMetadata.a == null) {
                CommodityChannelIndexIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CommodityChannelIndexIndicatorDescriptionMetadata.c(CommodityChannelIndexIndicatorDescriptionMetadata.a);
            }
            if (a.k(CommodityChannelIndexIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ab(CommodityChannelIndexIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
        }
        static d(a) {
            CommodityChannelIndexIndicatorDescriptionMetadata.b(a);
            a.ad("CommodityChannelIndexIndicator", () => new CommodityChannelIndexIndicatorDescription());
            a.ac("CommodityChannelIndexIndicator", CommodityChannelIndexIndicatorDescriptionMetadata.a);
        }
    }
    CommodityChannelIndexIndicatorDescriptionMetadata.$t = markType(CommodityChannelIndexIndicatorDescriptionMetadata, 'CommodityChannelIndexIndicatorDescriptionMetadata');
    CommodityChannelIndexIndicatorDescriptionMetadata.a = null;
    return CommodityChannelIndexIndicatorDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/CommodityChannelIndexIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { CommodityChannelIndexIndicatorDescription } from "./CommodityChannelIndexIndicatorDescription";
/**
 * @hidden
 */
export let CommodityChannelIndexIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class CommodityChannelIndexIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (CommodityChannelIndexIndicatorDescriptionMetadata.a == null) {
                CommodityChannelIndexIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CommodityChannelIndexIndicatorDescriptionMetadata.c(CommodityChannelIndexIndicatorDescriptionMetadata.a);
            }
            if (a.k(CommodityChannelIndexIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ac(CommodityChannelIndexIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
        }
        static d(a) {
            CommodityChannelIndexIndicatorDescriptionMetadata.b(a);
            a.ae("CommodityChannelIndexIndicator", () => new CommodityChannelIndexIndicatorDescription());
            a.ad("CommodityChannelIndexIndicator", CommodityChannelIndexIndicatorDescriptionMetadata.a);
        }
    }
    CommodityChannelIndexIndicatorDescriptionMetadata.$t = markType(CommodityChannelIndexIndicatorDescriptionMetadata, 'CommodityChannelIndexIndicatorDescriptionMetadata');
    CommodityChannelIndexIndicatorDescriptionMetadata.a = null;
    return CommodityChannelIndexIndicatorDescriptionMetadata;
})();
